@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2004 Georgy Yunaev tim@krasnogorsk.ru
+ * Copyright (C) 2004-2009 Georgy Yunaev gyunaev@ulduzsoft.com
  *
  * This library is free software; you can redistribute it and/or modify it 
  * under the terms of the GNU Lesser General Public License as published by 
@@ -10,8 +10,6 @@
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public 
  * License for more details.
- *
- * $Id: libircclient.h 43 2004-10-10 16:19:04Z gyunaev $
  */
 
 /*! 
@@ -47,9 +45,13 @@
 
 #if !defined (WIN32)
 	#include <sys/select.h>	/* fd_set */
-	#include <netinet/in.h>	/* sockaddr_in */
 #else
-	#include <winsock.h>
+	#include <winsock2.h>
+	#include <ws2tcpip.h>
+	#if defined (ENABLE_IPV6)
+		typedef int  (WSAAPI * getaddrinfo_ptr_t)  (const char *, const char* , const struct addrinfo *, struct addrinfo **);
+		typedef void (WSAAPI * freeaddrinfo_ptr_t) (struct addrinfo*);
+	#endif
 #endif
 
 #ifdef	__cplusplus
@@ -126,6 +128,7 @@ typedef void (*irc_dcc_callback_t) (irc_session_t * session, irc_dcc_t id, int s
 
 #define IN_INCLUDE_LIBIRC_H
 #include "libirc_errors.h"
+#include "libirc_rfcnumeric.h"
 #include "libirc_events.h"
 #include "libirc_options.h"
 
@@ -193,7 +196,7 @@ void irc_destroy_session (irc_session_t * session);
  * \param port    An IRC server port, usually 6667.
  * \param server_password  An IRC server password, if the server requires it.
  *                May be NULL, in this case password will not be send to the 
- *                IRC server.
+ *                IRC server. Vast majority of IRC servers do not require passwords.
  * \param nick    A nick, which libircclient will use to login to the IRC server.
  *                Must not be NULL.
  * \param username A username of the account, which is used to connect to the
@@ -228,6 +231,50 @@ int irc_connect (irc_session_t * session,
 			const char * realname);
 
 
+/*!
+ * \fn int irc_connect6 (irc_session_t * session, const char * server, unsigned short port, const char * server_password, const char * nick, const char * username, const char * realname);
+ * \brief Initiates a connection to IRC server using IPv6.
+ *
+ * \param session A session to initiate connections on. Must not be NULL.
+ * \param server  A domain name or an IP address of the IRC server to connect 
+ *                to. Must not be NULL.
+ * \param port    An IRC server port, usually 6667.
+ * \param server_password  An IRC server password, if the server requires it.
+ *                May be NULL, in this case password will not be send to the 
+ *                IRC server. Vast majority of IRC servers do not require passwords.
+ * \param nick    A nick, which libircclient will use to login to the IRC server.
+ *                Must not be NULL.
+ * \param username A username of the account, which is used to connect to the
+ *                IRC server. This is for information only, will be shown in
+ *                "user properties" dialogs and returned by /whois request.
+ *                May be NULL, in this case 'nobody' will be sent as username.
+ * \param realname A real name of the person, who connects to the IRC. Usually
+ *                people put some wide-available information here (URL, small
+ *                description or something else). This information also will 
+ *                be shown in "user properties" dialogs and returned by /whois 
+ *                request. May be NULL, in this case 'noname' will be sent as 
+ *                username.
+ *
+ * \return Return code 0 means success. Other value means error, the error 
+ *  code may be obtained through irc_errno(). Any error, generated by the 
+ *  IRC server, is available through irc_callbacks_t::event_numeric.
+ *
+ * This function prepares and initiates a connection to the IRC server. The
+ * connection is done asynchronously (see irc_callbacks_t::event_connect), so the success 
+ * return value means that connection was initiated (but not completed!)
+ * successfully.
+ *
+ * \sa irc_run
+ * \ingroup conndisc
+ */
+int irc_connect6 (irc_session_t * session, 
+			const char * server, 
+			unsigned short port,
+			const char * server_password,
+			const char * nick,
+			const char * username,
+			const char * realname);
+
 /*!
  * \fn void irc_disconnect (irc_session_t * session)
  * \brief Disconnects a connection to IRC server.
